<?php
/**
 * Configuration for "min", the default application built with the Minify
 * library
 * 
 * @package Minify
 */


/**
* Разрешить использование приложения Minify URI Builder. Только установите для этого значение true, когда оно вам нужно.
 */
$min_enableBuilder = false;


/**
 *Конкатенация, но не минимизация файлов. Это можно использовать для тестирования.
 */
$min_concatOnly = false;


/**
 * If non-empty, the Builder will be protected with HTTP Digest auth.
 * The username is "admin".
 */
$min_builderPassword = 'admin&icms';


/**
 * Set to true to log messages to FirePHP (Firefox Firebug addon).
 * Set to false for no error logging (Minify may be slightly faster).
 * @link http://www.firephp.org/
 *
 * If you want to use a custom error logger, set this to your logger
 * instance. Your object should have a method log(string $message).
 */
$min_errorLogger = false;


/**
 * Чтобы разрешить вывод режима отладки, установить эту опцию в значение true.
 * Можете отправить файл cookie minDebug для запроса вывода режима отладки. 
 * Значение cookie должно соответствовать URI, которые вы хотите отлаживать. Например. для отладки /min/f=file1.js отправить файл cookie minDebug = file1.js
 * Вы можете вручную включить отладку путем добавления "&debug" в URI.
 * типа. /min/?f=script1.js,script2.js&debug
 * В режиме «debug» Minify объединяет файлы без мини-кода и добавляет комментарии, чтобы указать строку #s исходных файлов.
 */
$min_allowDebugFlag = false;


/**
 * Для лучшей производительности укажите ваш каталог temp.
 * В противном случае Minify придется загрузить из директории примеры ниже:
 */
//$min_cachePath = 'c:\\WINDOWS\\Temp';
//$min_cachePath = '/tmp';
//$min_cachePath = preg_replace('/^\\d+;/', '', session_save_path());

/**
 * APC/Memcache/ZendPlatform для хранения кеша, требуется класс и  $ min_cachePath для экземпляра. Пример ниже
 */
//require dirname(__FILE__) . '/lib/Minify/Cache/APC.php';
//$min_cachePath = new Minify_Cache_APC();


/**
 * Оставьте пустую строку для использования PHP $_SERVER['DOCUMENT_ROOT'].
 *
 * На некоторых серверах это значение может быть неправильно сконфигурировано или отсутствует. Если это так, установите путь
 * к вашему полному корневому пути документа без конечной косой черты.
 * Например. '/ home / accountname / public_html' или 'c: \\ xampp \\ htdocs'
 *
 * Если / min / находится непосредственно внутри вашего корня документа, просто раскомментируйте 
 * вторая линия. 
 * Третья строка может работать на некоторых серверах Apache.
 */
$min_documentRoot = '';
//$min_documentRoot = substr(__FILE__, 0, -15);
//$min_documentRoot = $_SERVER['SUBDOMAIN_DOCUMENT_ROOT'];


/**
 * Блокировка кеша. Установите значение false, если файловая система - NFS. По крайней мере один
 * Попытки стекирования системы NFS затормозили PHP на 30 секунд!
 */
$min_cacheFileLocking = false;


/**
* Объединение нескольких файлов CSS может размещать объявления @import после правил, которые
  * является недействительным. Minify попытается обнаружить, когда это произойдет, и поместите
  * предупреждение в верхней части вывода CSS. Чтобы решить эту проблему, вы можете
  * переместите @imports внутри ваших файлов CSS или включите этот параметр, который будет
  * переместите все @imports в начало вывода. Обратите внимание, что перемещение @imports может
  * влияет на значения CSS (поэтому по умолчанию этот параметр отключен).
 */
$min_serveOptions['bubbleCssImports'] = false;


/**
* Cache-Control: максимальное значение, отправленное в браузер (в секундах). После этого периода,
  * браузер отправит еще одно условное GET. Используйте более длительный период для более низких
  *, но вы можете сократить это до внесения изменений, если это важно
  * Эти изменения видны немедленно.
  *
  * Примечание. Несмотря на эту настройку, если вы включили номер в конце
  * querystring, maxAge будет установлен на один год. Например. /min/f=hello.css&123456
 */
$min_serveOptions['maxAge'] = 1800;


/**
 * Чтобы использовать CSSmin (Túbal Martín's port of the YUI CSS compressor), раскомментируйте следующую строку:
 */
//$min_serveOptions['minifiers']['text/css'] = array('Minify_CSSmin', 'minify');


/**
* Использовать API Google Closure Compiler для минимизации Javascript (возврат к JSMin
  * при сбое), раскомментируйте следующую строку:
 */
//$min_serveOptions['minifiers']['application/x-javascript'] = array('Minify_JS_ClosureCompiler', 'minify');


/**
* Если вы хотите ограничить опцию «f» файлами внутри / ниже
  * конкретные каталоги ниже DOCUMENT_ROOT, установите это здесь.
  * Вам все равно нужно будет включить каталог в
  * f или b Параметры GET.
 * 
 * // = shortcut for DOCUMENT_ROOT 
 */
//$min_serveOptions['minApp']['allowDirs'] = array('//js', '//css');

/**
* Установите значение true, чтобы отключить параметр «f» GET для указания файлов.
  * Будет рассмотрен только параметр "g".
 */
$min_serveOptions['minApp']['groupsOnly'] = false;


/**
* По умолчанию Minify не будет минимизировать файлы с именами, содержащими .min или -min
  * до расширения. Например. myFile.min.js не будет обрабатываться JSMin
  *
  * Чтобы минимизировать все файлы, установите для этого параметра значение null. Вы также можете указать свой
  * собственный шаблон, сопоставляемый с именем файла.
 */
//$min_serveOptions['minApp']['noMinPattern'] = '@[-\\.]min\\.(?:js|css)$@i';


/**
* Если вы уменьшаете CSS-файлы, хранящиеся в каталогах symlink-ed, переписывание URI
  * алгоритм может выйти из строя. Чтобы предотвратить это, предоставьте массив путей ссылок для
  * целевые пути, где пути ссылок находятся внутри корня документа.
  * Поскольку пути должны быть нормализованы, чтобы это работало, используйте «//» для замены
  * корень doc в путях ссылок (ключи массива). Например.:
 * <code>
 * array('//symlink' => '/real/target/path') // unix
 * array('//static' => 'D:\\staticStorage')  // Windows
 * </code>
 */
//$min_symlinks = array('static' => 'D:\\usr\\domains/instantcms*****/cache/');
$min_symlinks = array();


/**
* Если вы загружаете файлы из Windows на не-Windows-сервер, Windows может сообщать
  * неправильные файлы для файлов. Это может привести к тому, что Minify будет поддерживать устаревание
  * кеш-файлы, когда изменения исходного файла сделаны слишком часто (например, больше, чем
  * один раз в час).
  *
  * Сразу после изменения и загрузки файла используйте команду touch для
  * обновить mtime на сервере. Если mtime перескакивает на несколько часов,
  * установите эту переменную на это число. Если mtime возвращается, это не должно быть
  * необходимо.
  *
  * В WinCCP для Windows SFTP-клиента есть опция, которая может исправить это
  * выпуск без изменения переменной ниже. В среде login>
  * выберите параметр «Adjust remote timestamp with DST».
 * @link http://winscp.net/eng/docs/ui_login_environment#daylight_saving_time
 */
$min_uploaderHoursBehind = 0;


/**
 * Path to Minify's lib folder. If you happen to move it, change 
 * this accordingly.
 */
$min_libPath = dirname(__FILE__) . '/lib';


// try to disable output_compression (may not have an effect)
ini_set('zlib.output_compression', '0');
